# 🌐 Jasper

The 2024 Jasper wildfire.

![image](https://kamangir-public.s3.ca-central-1.amazonaws.com/geo-watch-2024-09-06-Jasper-a/geo-watch-2024-09-06-Jasper-a-2X.gif?raw=true&random=mJahtfyzlU0VkVYT)

|   |   |   |
| --- | --- | --- |
| `2024-7-20` | `2024-7-22` | `2024-7-27` |
| ![image](https://kamangir-public.s3.ca-central-1.amazonaws.com/geo-watch-2024-09-06-Jasper-a/11_U_MU_2024_7_20_0_TCI.png) | ![image](https://kamangir-public.s3.ca-central-1.amazonaws.com/geo-watch-2024-09-06-Jasper-a/11_U_MU_2024_7_22_0_TCI.png) | ![image](https://kamangir-public.s3.ca-central-1.amazonaws.com/geo-watch-2024-09-06-Jasper-a/11_U_MU_2024_7_27_0_TCI.png) |

The fire originates in the bottom right, crosses the river, and causes the colors to shift from green to brown.

 - [Google Maps](https://maps.app.goo.gl/o5tGW4tH5S6j4vso9): `lat: 52.8734"N`, `lon: 118.0814"W`.
 - [Parks Canada](https://parks.canada.ca/pn-np/ab/jasper/visit/feu-alert-fire/feudeforet-wildfire): Wildfire status, Jasper Wildfire Complex.
 - [Wikipedia](https://en.wikipedia.org/wiki/2024_Jasper_wildfire)

---

used by: [`@geo watch`](../../).
